@@ -1273,6 +1273,19 @@ Rcpp::List SimSSMLinSDEIVary2(
   return output;
 }
 // -----------------------------------------------------------------------------
+// edit .setup/cpp/simStateSpace-solve-lya-dot.cpp
+// Ivan Jacob Agaloos Pesigan
+// -----------------------------------------------------------------------------
+
+#include <RcppArmadillo.h>
+// [[Rcpp::depends(RcppArmadillo)]]
+// [[Rcpp::export(.SolveLya)]]
+arma::mat SolveLya(arma::mat A, arma::mat Q) {
+  arma::mat X;
+  arma::syl(X, A, A.t(), Q);
+  return ((X + X.t()) / 2);
+}
+// -----------------------------------------------------------------------------
 // edit .setup/cpp/simStateSpace-solve-syl-dot.cpp
 // Ivan Jacob Agaloos Pesigan
 // -----------------------------------------------------------------------------
